@@ -86,16 +86,27 @@ DEFAULTS = {
             'close_button_on_tab'   : True,
             'hide_tabbar'           : False,
             'scroll_tabbar'         : False,
+            'hide_from_taskbar'     : False,
+            'always_on_top'         : False,
+            'hide_on_lose_focus'    : False,
+            'sticky'                : False,
             'try_posix_regexp'      : platform.system() != 'Linux',
+            'use_custom_url_handler': False,
+            'custom_url_handler'    : '',
+            'disable_real_transparency' : False,
+            'title_hide_sizetext'   : False,
             'title_transmit_fg_color' : '#ffffff',
             'title_transmit_bg_color' : '#c80003',
             'title_receive_fg_color' : '#ffffff',
             'title_receive_bg_color' : '#0076c9',
             'title_inactive_fg_color' : '#000000',
             'title_inactive_bg_color' : '#c0bebf',
+            'inactive_color_offset': 0.8,
             'enabled_plugins'       : ['LaunchpadBugURLHandler',
                                        'LaunchpadCodeURLHandler',
                                        'APTURLHandler'],
+             'suppress_multiple_term_dialog': False,
+             'always_split_with_profile': False,
         },
         'keybindings': {
             'zoom_in'          : '<Control>plus',
@@ -110,6 +121,8 @@ DEFAULTS = {
             'go_down'          : '<Alt>Down',
             'go_left'          : '<Alt>Left',
             'go_right'         : '<Alt>Right',
+            'rotate_cw'        : '<Super>r',
+            'rotate_ccw'       : '<Super><Shift>r',
             'split_horiz'      : '<Shift><Control>o',
             'split_vert'       : '<Shift><Control>e',
             'close_term'       : '<Shift><Control>w',
@@ -150,7 +163,10 @@ DEFAULTS = {
             'new_terminator'   : '<Super>i',
             'broadcast_off'    : '',
             'broadcast_group'  : '',
-            'broadcast_all'    : ''
+            'broadcast_all'    : '',
+            'insert_number'    : '',
+            'insert_padded'    : '',
+            'edit_window_title': ''
         },
         'profiles': {
             'default':  {
@@ -171,6 +187,8 @@ DEFAULTS = {
                 'cursor_shape'          : 'block',
                 'cursor_color'          : '#aaaaaa',
                 'emulation'             : 'xterm',
+                'term'                  : 'xterm',
+                'colorterm'             : 'gnome-terminal',
                 'font'                  : 'Mono 10',
                 'foreground_color'      : '#aaaaaa',
                 'show_titlebar'         : True,
@@ -337,9 +355,10 @@ class Config(object):
                 self.gconf = gconf.client_get_default()
 
             value = self.gconf.get('/apps/metacity/general/focus_mode')
-            self.system_focus = value.get_string()
-            self.gconf.notify_add('/apps/metacity/general/focus_mode',
-                    self.on_gconf_notify)
+            if value:
+                self.system_focus = value.get_string()
+                self.gconf.notify_add('/apps/metacity/general/focus_mode',
+                        self.on_gconf_notify)
             return(self.system_focus)
 
     def on_gconf_notify(self, _client, _cnxn_id, _entry, _what):
@@ -413,6 +432,8 @@ class ConfigBase(Borg):
         Borg.__init__(self, self.__class__.__name__)
 
         self.prepare_attributes()
+        import optionparse
+        self.command_line_options = optionparse.options
         self.load()
 
     def prepare_attributes(self):
@@ -460,6 +481,9 @@ class ConfigBase(Borg):
 
             keytype = '%s(default=%s)' % (keytype, value)
 
+            if key == 'custom_url_handler':
+                keytype = 'string(default="")'
+
             section[key] = keytype
         configspecdata['global_config'] = section
 
@@ -479,6 +503,8 @@ class ConfigBase(Borg):
                 keytype = keymap[keytype]
             elif keytype == 'list':
                 value = 'list(%s)' % ','.join(value)
+            if key == 'background_image':
+                keytype = 'string'
             if keytype == 'string':
                 value = '"%s"' % value
 
@@ -512,7 +538,14 @@ class ConfigBase(Borg):
             dbg('ConfigBase::load: config already loaded')
             return
 
-        filename = os.path.join(get_config_dir(), 'config')
+        if self.command_line_options:
+            if not self.command_line_options.config:
+                self.command_line_options.config = os.path.join(get_config_dir(), 'config')
+            filename = self.command_line_options.config
+        else:
+            filename = os.path.join(get_config_dir(), 'config')
+
+        dbg('looking for config file: %s' % filename)
         try:
             configfile = open(filename, 'r')
         except Exception, ex:
@@ -607,7 +640,7 @@ class ConfigBase(Borg):
         if not os.path.isdir(config_dir):
             os.makedirs(config_dir)
         try:
-            parser.write(open(os.path.join(config_dir, 'config'), 'w'))
+            parser.write(open(self.command_line_options.config, 'w'))
         except Exception, ex:
             err('ConfigBase::save: Unable to save config: %s' % ex)
 
